==> postcss-rtl-1.3.3.tgz: package/lib/options.js <==
'use strict';

var defaultOptions = {
  addPrefixToSelector: false, // customized function for joining prefix and selector
  prefixType: 'attribute', // type of dir-prefix: attribute [dir] or class .dir,
  onlyDirection: false, // "ltr", "rtl": compile only one-direction version
  removeComments: true // remove comments after process them
};

var validateOptions = function validateOptions() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var addPrefixToSelector = options.addPrefixToSelector,
      prefixType = options.prefixType,
      onlyDirection = options.onlyDirection,
      removeComments = options.removeComments;

  var fixedOptions = {};

  if (addPrefixToSelector && typeof addPrefixToSelector !== 'function') {
    fixedOptions.addPrefixToSelector = defaultOptions.addPrefixToSelector;
    console.warn('Incorrect addPrefixToSelector option. Must be a function');
  }

  if (onlyDirection && typeof onlyDirection !== 'string') {
    fixedOptions.onlyDirection = defaultOptions.onlyDirection;
    console.warn('Incorrect onlyDirection option. Allowed values: ltr, rtl');
  }

  if (prefixType && ['attribute', 'class'].indexOf(prefixType) < 0) {
    fixedOptions.prefixType = defaultOptions.prefixType;
    console.warn('Incorrect prefixType option. Allowed values: attribute, class');
  }

  if (prefixType && ['attribute', 'class'].indexOf(prefixType) < 0) {
    fixedOptions.prefixType = defaultOptions.prefixType;
    console.warn('Incorrect prefixType option. Allowed values: attribute, class');
  }

  if (removeComments && typeof removeComments !== 'boolean') {
    fixedOptions.removeComments = defaultOptions.removeComments;
    console.warn('Incorrect removeComments option. Must be a boolean');
  }

  return Object.assign({}, defaultOptions, options, fixedOptions);
};

module.exports = {
  validateOptions: validateOptions
};

==> postcss-rtl-1.4.0.tgz: package/lib/options.js <==
"use strict";

const defaultOptions = {
  addPrefixToSelector: false,
  // customized function for joining prefix and selector
  prefixType: 'attribute',
  // type of dir-prefix: attribute [dir] or class .dir,
  onlyDirection: false,
  // "ltr", "rtl": compile only one-direction version
  fromRTL: false,
  // assume styles are written in rtl initially
  removeComments: true // remove comments after process them

};
/* eslint-disable no-console */

const validateOptions = (options = {}) => {
  const addPrefixToSelector = options.addPrefixToSelector,
        prefixType = options.prefixType,
        onlyDirection = options.onlyDirection,
        removeComments = options.removeComments,
        fromRTL = options.fromRTL;
  const fixedOptions = {};

  if (addPrefixToSelector && typeof addPrefixToSelector !== 'function') {
    fixedOptions.addPrefixToSelector = defaultOptions.addPrefixToSelector;
    console.warn('Incorrect addPrefixToSelector option. Must be a function');
  }

  if (onlyDirection && typeof onlyDirection !== 'string') {
    fixedOptions.onlyDirection = defaultOptions.onlyDirection;
    console.warn('Incorrect onlyDirection option. Allowed values: ltr, rtl');
  }

  if (prefixType && ['attribute', 'class'].indexOf(prefixType) < 0) {
    fixedOptions.prefixType = defaultOptions.prefixType;
    console.warn('Incorrect prefixType option. Allowed values: attribute, class');
  }

  if (prefixType && ['attribute', 'class'].indexOf(prefixType) < 0) {
    fixedOptions.prefixType = defaultOptions.prefixType;
    console.warn('Incorrect prefixType option. Allowed values: attribute, class');
  }

  if (removeComments && typeof removeComments !== 'boolean') {
    fixedOptions.removeComments = defaultOptions.removeComments;
    console.warn('Incorrect removeComments option. Must be a boolean');
  }

  if (fromRTL && typeof fromRTL !== 'boolean') {
    fixedOptions.removeComments = defaultOptions.removeComments;
    console.warn('Incorrect fromRTL option. Must be a boolean');
  }

  return Object.assign({}, defaultOptions, options, fixedOptions);
};
/* eslint-enable no-console */


module.exports = {
  validateOptions
};
